@@ -14,6 +14,8 @@
 
 package Google::Ads::Common::XPathSAXParser;
 
+use strict;
+use warnings;
 use version;
 
 # The following needs to be on one line because CPAN uses a particularly hacky
